;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "python-mode" "20250930.608"
  "Python major mode."
  ()
  :url "https://gitlab.com/groups/python-mode-devs"
  :commit "5aaf8b386aa694429d997c6fd49772b0b359e514"
  :revdesc "5aaf8b386aa6"
  :keywords '("python" "languages" "oop")
  :maintainers '((nil . "python-mode@python.org")))
